@@ -6,7 +6,7 @@ from sentry_sdk import init
 
 def setup_logger(debug: bool) -> None:
     logger.remove()
-    logger.add(sys.stdout, level='DEBUG' if debug else 'INFO')
+    logger.add(sys.stdout, level='DEBUG' if debug else 'INFO', serialize=True)
 
 
 def setup_sentry(dsn: str, environment: str, sample_rate=0.2) -> None:
